@@ -171,6 +171,7 @@ class TimeCategories(object):
 	_REST_SECTION = 4
 	_MAX_SECTIONS = 5
 
+	_NO_ELAPSED = datetime.timedelta(hours=1)
 	_WEEK_ELAPSED = datetime.timedelta(weeks=1)
 	_MONTH_ELAPSED = datetime.timedelta(days=30)
 
@@ -203,9 +204,9 @@ class TimeCategories(object):
 		elapsedTime = self._today - rowDate
 		todayTuple = self._today.timetuple()
 		rowTuple = rowDate.timetuple()
-		if todayTuple[0:4] == rowTuple[0:4]:
+		if elapsedTime < self._NO_ELAPSED:
 			section = self._NOW_SECTION
-		if todayTuple[0:3] == rowTuple[0:3]:
+		elif todayTuple[0:3] == rowTuple[0:3]:
 			section = self._TODAY_SECTION
 		elif elapsedTime < self._WEEK_ELAPSED:
 			section = self._WEEK_SECTION
@@ -215,6 +216,11 @@ class TimeCategories(object):
 			section = self._REST_SECTION
 		self._timeItems[section].appendRow(row)
 
+	def get_item(self, timeIndex, rowIndex, column):
+		timeItem = self._timeItems[timeIndex]
+		item = timeItem.child(rowIndex, column)
+		return item
+
 
 class History(object):
 
@@ -341,27 +347,33 @@ class History(object):
 	@QtCore.pyqtSlot(QtCore.QModelIndex)
 	@misc_utils.log_exception(_moduleLogger)
 	def _on_row_activated(self, index):
-		rowIndex = index.row()
-		item = self._itemStore.item(rowIndex, 0)
-		contactDetails = item.data().toPyObject()
+		timeIndex = index.parent()
+		assert timeIndex.isValid()
+		timeRow = timeIndex.row()
+		row = index.row()
+		detailsItem = self._categoryManager.get_item(timeRow, row, self.DETAILS_IDX)
+		fromItem = self._categoryManager.get_item(timeRow, row, self.FROM_IDX)
+		contactDetails = detailsItem.data().toPyObject()
 
-		title = str(self._itemStore.item(rowIndex, self.FROM_IDX).text())
+		title = str(fromItem.text())
 		number = str(contactDetails[QtCore.QString("number")])
 		contactId = number # ids don't seem too unique so using numbers
 
 		descriptionRows = []
-		for i in xrange(self._itemStore.rowCount()):
-			iItem = self._itemStore.item(i, 0)
-			iContactDetails = iItem.data().toPyObject()
-			iNumber = str(iContactDetails[QtCore.QString("number")])
-			if number != iNumber:
-				continue
-			relTime = misc_utils.abbrev_relative_date(iContactDetails[QtCore.QString("relTime")])
-			action = str(iContactDetails[QtCore.QString("action")])
-			number = str(iContactDetails[QtCore.QString("number")])
-			prettyNumber = misc_utils.make_pretty(number)
-			rowItems = relTime, action, prettyNumber
-			descriptionRows.append("<tr><td>%s</td></tr>" % "</td><td>".join(rowItems))
+		for t in xrange(self._itemStore.rowCount()):
+			randomTimeItem = self._itemStore.item(t, 0)
+			for i in xrange(randomTimeItem.rowCount()):
+				iItem = randomTimeItem.child(i, 0)
+				iContactDetails = iItem.data().toPyObject()
+				iNumber = str(iContactDetails[QtCore.QString("number")])
+				if number != iNumber:
+					continue
+				relTime = misc_utils.abbrev_relative_date(iContactDetails[QtCore.QString("relTime")])
+				action = str(iContactDetails[QtCore.QString("action")])
+				number = str(iContactDetails[QtCore.QString("number")])
+				prettyNumber = misc_utils.make_pretty(number)
+				rowItems = relTime, action, prettyNumber
+				descriptionRows.append("<tr><td>%s</td></tr>" % "</td><td>".join(rowItems))
 		description = "<table>%s</table>" % "".join(descriptionRows)
 		numbersWithDescriptions = [(str(contactDetails[QtCore.QString("number")]), "")]
 		self._session.draft.add_contact(contactId, title, description, numbersWithDescriptions)
@@ -552,8 +564,11 @@ class Messages(object):
 	@QtCore.pyqtSlot(QtCore.QModelIndex)
 	@misc_utils.log_exception(_moduleLogger)
 	def _on_row_activated(self, index):
-		rowIndex = index.row()
-		item = self._itemStore.item(rowIndex, 0)
+		timeIndex = index.parent()
+		assert timeIndex.isValid()
+		timeRow = timeIndex.row()
+		row = index.row()
+		item = self._categoryManager.get_item(timeRow, row, 0)
 		contactDetails = item.data().toPyObject()
 
 		name = str(contactDetails[QtCore.QString("name")])
